%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Metzen et al. Neural correlations enable invariant coding and perception
% of natural stimuli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% data correlations to chirps; recombined
% V1 - May 13th 2015; Michael Metzen
% this code either recombines single neurons or takes the pairs of
% simultaneously recorded pairs and computes the correlated activity as
% well as the firingrates in response to different chirp stimuli
% at the end, there is an output file that contains PSTHs of the
% Firingrates and the correlated activity in a 4s window with the chirp
% centered; the output file will be saved accordingly and is needed for the
% subsequent analysis (Invariance measure, tuning plot)
% for saving, a folder C:\outs has to be existant
% NOTE: this sscript runs for quite a long time! For demonstration just
% tell the for-loop in line 70 to run for 1 element!

clear
close all
frage=1;
folderi=[4];    % location to save output file (4Hz)
% the next input determins if you want to analyse single or dual recordings
% for single recordings: ENTER 1
% for dual recorings: ENTER 2
dual=input('analyze single (1) or dual (2) recorings? ');
%%
% move to the folder that contains the processed files!
locationB=['F:\Maso_data_backup\Chirps\PUNITS\processed\dual\chirps\4Hz'];
cd([locationB])
FileList=dir('*.mat');
n=size(FileList,1);
% use all possible pairings of p-units (single units)
for II=1:n
    load(FileList(II).name);
    [~,name]=fileparts(FileList(II).name);
    temp=size(eval(name),2);
    if dual==2
        display('Analyzing DUAL recordings')
        temp1=nchoosek(1:1:temp,2);
        temp2=diff(temp1,1,2);
        ind=find(temp1==1);
        neurons{II}=temp1(ind,:);
    else
        display('Analyzing SINGLE recordings')
        neurons{II}=nchoosek(1:1:temp,2);
    end 
    keep FileList folderi frage II n neurons dual locationB
end

% account for different sizes
maxN=max([max(size(neurons{1,1},1)) max(size(neurons{1,2},1)) max(size(neurons{1,3},1)) max(size(neurons{1,4},1)) max(size(neurons{1,5},1)) ...
    max(size(neurons{1,6},1)) max(size(neurons{1,7},1)) max(size(neurons{1,8},1))]);
for II=1:8
   if size(neurons{1,II},1)<maxN
       temp=vertcat(neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II},neurons{1,II});
       neurons{1,II}=temp(1:maxN,:);
       clear temp      
   else
       
   end
    
end
neurons1=neurons{1,1};
neurons2=neurons{1,2};
neurons3=neurons{1,3};
neurons4=neurons{1,4};
neurons5=neurons{1,5};
neurons6=neurons{1,6};
neurons7=neurons{1,7};
neurons8=neurons{1,8};

%%
grname=1:1:length(neurons1);
for MG=1:length(neurons1)
    fol=folderi(1);
    folmaso=grname(MG);
    % single units
    locationC=['C:\outs\']; % PC
    % DUAL
%     locationC=['C:\outsdual\']; % path to save the output files
    locationS=[locationB];
    locationSC=[locationC]; % saving location
    cd([locationS])
    warning off
    FileList=dir('*.mat');
    nn=size(FileList,1);
    out=[];
   
    % to keep the comptationtime short, I set the skcwin_vect to contain
    % only one value!
    if frage==0
         winsize=2; % 2 for 2-5; 8 for 2:2:20
         spkcwin_vect=5;%linspace(2,5,5);
    elseif frage==1
         winsize=8; % 2 for 2-5; 8 for 2:2:20
         spkcwin_vect=8;%(2:2:20);
    end

    for UUU=1:length(spkcwin_vect)
        spkwin=spkcwin_vect(UUU);
        UUU=4;  % if spkcwin_vect is set to one value only, include this line
        if UUU==1
            if frage==0
                foldS=['0.5'];
            else
                foldS=['2'];
            end
        elseif UUU==2
            if frage==0
                foldS=['0.7'];
            else
                foldS=['4'];
            end
        elseif UUU==3
            if frage==0
                foldS=['0.9'];
            else
                foldS=['6'];
            end
        elseif UUU==4
            if frage==0
                foldS=['1.1'];
            else
                foldS=['8'];
            end
        elseif UUU==5
            if frage==0
                foldS=['1.3'];
            else
                foldS=['10'];
            end
        elseif UUU==6
            foldS=['12'];
        elseif UUU==7
            foldS=['14'];
        elseif UUU==8
            foldS=['16'];
        elseif UUU==9
            foldS=['18'];
        elseif UUU==10
            foldS=['20'];
        end
        % computes the results for the different chirp phases...
        for daun=1:nn
            if daun==9
            else
                keep frage grname folmaso winsize nn FileList out spkcwin_vect spkwin UUU locationS fol MG folderi foldS locationSC locationC locationB daun neurons1 neurons2 neurons3 neurons4 neurons5 neurons6 neurons7 neurons8
                cd([locationS])
                load(FileList(daun).name);
                tmp=whos;
                tmp=tmp(3);
                filename=tmp.name;
                datamat=eval(tmp.name);
                for I=1:length((datamat))
                    maxdatapoints(I)=length(datamat(I).bin);
                    maxdatapointsS(I)=length(datamat(I).stim);
                end
                lengleng=length(datamat);
                temp=find(maxdatapoints-maxdatapointsS>0);
                if isempty(temp)
                    temp=find(maxdatapoints-maxdatapointsS<0);
                    maxdatapoints=maxdatapoints;
                    for I=1:length(temp)
                        datamat(temp(I)).stim=datamat(temp(I)).stim(1:maxdatapoints(temp(I)));
                    end
                else
                    maxdatapoints=maxdatapointsS;
                    for I=1:length(temp)
                        datamat(temp(I)).bin=datamat(temp(I)).bin(1:maxdatapointsS(temp(I)));
                    end
                end
                clear temp I
                
                chirptimes=datamat(find(max(maxdatapoints))).ctimes;
                stim=zeros(max(maxdatapoints),length(datamat));
                stim(stim==0)=NaN;
                binaries=zeros(max(maxdatapoints),length(datamat));
                for I=1:length((datamat))
                    stim(1:maxdatapoints(I),I)=datamat(I).stim;
                    binaries(1:maxdatapoints(I),I)=datamat(I).bin;
                end
                
                beat=4;
                name_chirp=str2num(filename(end));
                                
                warning off
                n=size(binaries,2);
                out=[];
                 % phase locking index
                % first cut out all chirps..
                binnew=binaries;
                for III=1:size(binnew,2)
                    cutt=min(find(isnan(stim(:,III))))-1;
                    if isempty(cutt)
                        cutt=length(stim(:,III));
                        yep=III;
                    end
                end
                             
                time=(size(stim,1)/10000);
                oldaxis=(1:1:size(stim,1))./10000;
                newSR=(10000*beat); % make it timeindepentend
                maxdatapoints=maxdatapoints./10000*newSR;
                newaxis=(1:1:size(stim,1)*(newSR/10000))./newSR;
                stimulus_long=interp1(oldaxis,stim(:,yep),newaxis,'spline');
                endenew=length(stimulus_long);
                %
                mastermat=zeros(endenew,n);
                for I=1:n
                    spk1=(find(binaries(:,I)==1))/10000;
                    spk1=spk1+0.0025;
                    indis1=round(spk1*newSR);
                    indis1=indis1(find(indis1>0));
                    binatemp=zeros(endenew+1000,1);
                    binatemp(indis1)=1;
                    mastermattemp(1:endenew,:)=binatemp(1:endenew,:);
                    mastermat(1:endenew,I)=mastermattemp(1:endenew,:);
                    clear spk1 indis1 binatemp mastermattemp
                end
                mastermat=mastermat';
                [~,ll]=findpeaks(stimulus_long);
                cycldur=ll(3)-ll(2);
                stepdur=0.001;
                warning off
                win=round(cycldur/winsize);
                steps=round(cycldur*stepdur);
                spwin=round(win/spkwin);
                tbin=1/newSR;
                
                numneurons=2;
                numneur=size(mastermat,1);
                number=floor(round(size(mastermat,2)/steps)-win/steps);
                
                % now make all possible pairs and compute the corr
                pairs=nchoosek(1:1:numneur,numneurons);
                if daun==1
                    take=neurons1(MG,:);
                elseif daun==2
                    take=neurons1(MG,:);
                elseif daun==3
                    take=neurons3(MG,:);
                elseif daun==4
                    take=neurons4(MG,:);
                elseif daun==5
                    take=neurons5(MG,:);
                elseif daun==6
                    take=neurons6(MG,:);
                elseif daun==7
                    take=neurons7(MG,:);
                elseif daun==8
                    take=neurons8(MG,:);
                end
                ind=find(pairs(:,1)==take(1) & pairs(:,2)==take(2));
                pairs=pairs(ind,:);
                % get geometric means of p-value and CV of the pairs used in analysis
                CVtemp=zeros(length(pairs),2);
                pvaltemp=zeros(length(pairs),2);
                size(pairs,1)
                for I=1:size(pairs,1)
                    CVtemp(I,1)=datamat(pairs(I,1)).CV;
                    CVtemp(I,2)=datamat(pairs(I,2)).CV;
                    pvaltemp(I,1)=datamat(pairs(I,1)).pvalue;
                    pvaltemp(I,2)=datamat(pairs(I,2)).pvalue;
                    maxdur(I,1)=maxdatapoints(pairs(I,1));
                    maxdur(I,2)=maxdatapoints(pairs(I,2));
                end
                
                for ABC=1:size(pairs,1);
                    ABC
                    tic
                    for III=1:numneurons
                        bina(III,:)=mastermat(pairs(ABC,III),:);
                    end
                    cutt=maxdur(ABC,:); % to account for the min recoding lenght within the pair
                    stimulus=stimulus_long(1:min(cutt));
                    bina=bina(:,1:min(cutt));
                    
                    % align responses
                    if beat<10
                        fil_t=0.001;
                        [b,a]=butter(2,fil_t);
                    elseif beat>=10
                        fil_t=0.0003;
                        [b,a]=butter(2,fil_t);
                    end
                    maxlags=10000;
                    [c,lags]=xcorr(filtfilt(b,a,bina(1,:))-mean(filtfilt(b,a,bina(1,:))),filtfilt(b,a,bina(2,:))-mean(filtfilt(b,a,bina(2,:))),maxlags,'coeff');
                    lag1=find(c==max(c))-10001;
                    if lag1<0
                        lag1=-lag1;
                        temp=[bina(2,(lag1+1:end)) bina(2,(1:lag1))];
                    else
                        temp=[bina(2,(end-lag1+1:end)) bina(2,(1:end-lag1))];
                    end
                    bina(2,:)=temp;
                    
                    number=floor(round(size(bina,2)/steps)-win/steps);
                    CV_geom(ABC)=sqrt(CVtemp(ABC,1)*CVtemp(ABC,2));
                    pval_geom(ABC)=sqrt(pvaltemp(ABC,1)*pvaltemp(ABC,2));
                    avestim=zeros(number,1);
                    for ii=1:number
                       %
                        guchi=bina(:,steps*(ii-1)+1:steps*(ii-1)+win);
                        avestim(ii)=mean(stimulus(steps*(ii-1)+1:steps*(ii-1)+win));
                        for m=1:numneurons
                            for n=1:floor(length(guchi)/spwin)
                                seq(m,n)=length(find(guchi(m,spwin*(n-1)+1:spwin*n)));
                            end
                            rate(m,ii)=(length(find(guchi(m,:))))/win/tbin;
                        end
                        qq=1;
                        for m=1:numneurons-1
                            for n=m+1:numneurons
                                micorr=corrcoef(seq(m,:),seq(n,:));
                                rc(qq,ii)=(micorr(1,2));
                                qq=qq+1;
                            end
                        end
                        clear seq
                        rc(find(isnan(rc)==1))=1;
                    end
                    rc=rc(:);
                    R(1:length(rc),ABC)=(rc);
                    FR1(1:length(rate(1,:)),ABC)=rate(1,:);
                    FR2(1:length(rate(2,:)),ABC)=rate(2,:);
                    meanrate(1:length(mean(rate,1)),ABC)=mean(rate,1);
                    clear bina avx avy rc %rate
                    toc
                end
                R(find(isnan(R)==1))=1;
                Rnew=mean(R,2);
                
                cycl=cycldur/steps; % datapoints of 1 period
                dur=round(cycl*2); % duration for psth
                chirp_indices=(chirptimes./10000)*(1/stepdur)*beat;
                chirp_indices=chirp_indices(find(chirp_indices>dur & chirp_indices<length(avestim)-dur));
                
                signal_new=avestim(chirp_indices(1)-round(dur):chirp_indices(1)+round(dur));
                signal_new=signal_new';
                signal_new=2*(signal_new-min(signal_new))/(max(signal_new)-min(signal_new))-1;
                signal_newnew=stimulus((chirp_indices(1)*(steps))-round(dur*(steps)):(chirp_indices(1)*(steps))+round(dur*(steps)));
                signal_newnew=2*(signal_newnew-min(signal_newnew))/(max(signal_newnew)-min(signal_newnew))-1;
                boxc=60; % in ms
                close all
                
                for GH=1:size(R,2);
                    timeindex=round(cycl/2);    %100ms
                    psth1=zeros(round(dur*2),1);psth2=psth1;
                    spiketimesA=R(:,GH);
                    spiketimesB=meanrate(:,GH);
                    for II=1:length(chirp_indices); %correlations
                        spiketimes=spiketimesA(chirp_indices(II)-round(dur):chirp_indices(II)+round(dur));
                        if length(spiketimes)>0
                            if length(spiketimes)<length(psth1)
                                temp=length(psth1)-length(spiketimes);
                                temp1=zeros(temp,1);
                                spiketimes=[spiketimes;temp1];
                            end
                            if length(spiketimes)>length(psth1)
                                temp=length(spiketimes)-length(psth1);
                                spiketimes=spiketimes(1:end-temp);
                            end
                            psth1=psth1+spiketimes;
                        end
                    end
                    psth1=psth1/length(chirp_indices);
                    
                    for II=1:length(chirp_indices); %single FR
                        spiketimesrate=spiketimesB(chirp_indices(II)-round(dur):chirp_indices(II)+round(dur));
                        if length(spiketimesrate)>0
                            if length(spiketimesrate)<length(psth2)
                                temp=length(psth2)-length(spiketimesrate);
                                temp1=zeros(temp,1);
                                spiketimesrate=[spiketimesrate;temp1];
                            end
                            if length(spiketimesrate)>length(psth2)
                                temp=length(spiketimesrate)-length(psth2);
                                spiketimesrate=spiketimesrate(1:end-temp);
                            end
                            psth2=psth2+spiketimesrate;
                        end
                    end
                    psth2=psth2/length(chirp_indices);
                    A=ones(1,boxc);
                    A=A/length(A);
                    psth1=conv(A,psth1);
                    psth2=conv(A,psth2);
                    psth1=psth1(1:end-length(A)+1);
                    psth2=psth2(1:end-length(A)+1);
                    
                    % chirp selectivity index
                    CI_chirp=max(psth1(round(length(psth1)/2):round(length(psth1)/2)+timeindex))-min(psth1(round(length(psth1)/2):round(length(psth1)/2)+timeindex));
                    CI_beat=max(psth1((length(psth1)/2/4):round(length(psth1)/2-timeindex)))-min(psth1((length(psth1)/2/4):round(length(psth1)/2-timeindex)));
                    chirp_selectivity_indexR=((CI_chirp-CI_beat)/(CI_chirp+CI_beat));
                    delay=min(((find(psth1==max(psth1(round(length(psth1)/2):round(length(psth1)/2)+timeindex))))-(round(length(psth1)/2))))/1000; % corr reponse delay after chirp onset in sec
                    
                    CI_chirpFR=max(psth2(round(length(psth2)/2):round(length(psth2)/2)+timeindex))-min(psth2(round(length(psth2)/2):round(length(psth2)/2)+timeindex));
                    CI_beatFR=max(psth2((length(psth1)/2/4):round(length(psth2)/2-timeindex)))-min(psth2((length(psth1)/2/4):round(length(psth2)/2-timeindex)));
                    chirp_selectivity_indexFR=((CI_chirpFR-CI_beatFR)/(CI_chirpFR+CI_beatFR));
                    
                    corr_matrix(:,GH)=psth1(round(length(psth1)/2)-100:round(length(psth1)/2)+100);
                    FR_matrix(:,GH)=psth2(round(length(psth2)/2)-100:round(length(psth2)/2)+100);
                    SC_matrix(:,GH)=signal_newnew(round(length(signal_newnew)/2)-1000:round(length(signal_newnew)/2)+1000);
                    psth_corr(:,GH)=psth1;
                    psth_FR(:,GH)=psth2;
                    
                    out(GH,1)=GH;
                    out(GH,2)=beat;
                    out(GH,3)=name_chirp;
                    out(GH,4)=CI_chirp;
                    out(GH,5)=CI_beat;
                    out(GH,6)=chirp_selectivity_indexR;
                    out(GH,7)=CI_chirpFR;
                    out(GH,8)=CI_beatFR;
                    out(GH,9)=chirp_selectivity_indexFR;
                    out(ABC,10)=pval_geom(GH);
                    out(ABC,11)=CV_geom(GH);
                    out(GH,12)=pairs(GH,1);
                    out(GH,13)=pairs(GH,2);
                    out(GH,14)=delay;
                    out(GH,15)=spkwin;
                end
                % save output    
                mkdir('c:\outs\',['gr' num2str(folmaso)])
                cd(['c:\outs\','gr' num2str(folmaso)])
                mkdir(num2str(foldS))
                cd([locationSC 'gr' num2str(folmaso) '\' foldS])
                nam1=('_out_');
                nam2=('.mat');
                nam3=num2str(spkwin);
                save([num2str(beat) 'Hz' '_SC' num2str(daun) nam1 num2str(spkwin) nam2],'out','mastermat','timeindex','cycl','psth_corr','psth_FR','corr_matrix','FR_matrix','SC_matrix','signal_newnew')
                clear delay maxCI_chirpB maxCI_beatB chirp_selectivity_indexRB maxCI_chirpFR maxCI_beatFR chirp_selectivity_indexFR psth1 psth2 spiketimesA spiketimesB spiketimesrate
                clear R FR1 FR2 meanrate avestim guchi bina stimulus signal_new signal_newnew
            end
        end
    end
end

