%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Metzen et al. Neural correlations enable invariant coding and perception
% of natural stimuli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% analysis of echo responses to small chirps
% long-time recordings
% Maso MAR 2015
% updare March 27th 2015
% USE WITH RECORDINGS WITH PRIMING...
% extracts data from raw matlab files for different beats

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   I M P O R T A T   N O T E S:    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% recordings are made in the trigger mode in spike2
% this code needs *.mat files! (export from Spike2 to Matlab, see below!)
% a full recoding might be too long; cut the file in spike2 in pieces of
% 15 epochs each (but make sure that you set the cut point after the last0
% chirp-tripper of a AM epoch! (does not count for the very last AM epoch :-) )
%
% export the file in spike2, using the following seetings:
% 1st window: add all channels; chck 'time shift data'; export
% 2nd window: uncheck 'use source name.. '; check 'align and bin all data' and set the value to be 10000; check 'generate times for binned data'
%
% EXPORTING TAKES A WHILE!!! And the files are large!
% Don't forget to change the save name at the end!
% And don't forget to change the bfblocks (if neccessary)!!!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
close all
clear all

location=['F:\eLife\behavior\raw_data_matlab']; % pc (path and filename)
locationS=['F:\eLife\behavior\extracted_data']; % PC; location to save the processed data
cd([location])
% get the mat file(s)
FileList=dir('*.mat');
n=size(FileList,1);
phEODvect=[900*ones(1,8) 900*ones(1,8) 1100*ones(1,8) 990*ones(1,8) 920 1070 1010 950 910 955 830 1000 1030 1000 1020 1000 950 940 945 930 ...
    1056 1050 1030 960 970 1017 980 910 930]; % phaselocking EOD frequency;

for cca=1   %
    for FL=1:n
        phEOD=phEODvect(FL);
        crit2=3; % chirp count window, in s
        cd([location])
        load(FileList(FL).name);
        [~,name]=fileparts(FileList(FL).name)
        savename1=['001_behavior_fish1_run'];  % index number of fish (3 digits) - date
        savename2=name(end-4:end);
        if cca==1
            CA=1;
            exten=['_SC.mat'];    % SC small chirp - BC big chirp
        elseif cca==2
            CA=2;
            exten=['_BC.mat'];    % SC small chirp - BC big chirp
        elseif cca==3
            CA=3;
            exten=['_AC.mat'];    % SC small chirp - BC big chirp
        end
        ftresh=130; % BC frequency threshold according to Bastian et al 2001
        ftresh2=15; % SC frequency threshold according to Bastian et al 2001
        
        % type in order of beat frequency blocks - important!
        bfblocks=[4];   %that is the default export situation
        
        cd('F:\eLife\behavior\stimulus') % pc
        load('stimuli.mat')
        
        % get the number of beat blocks
        numbeat4=length(find(bfblocks==4));
        
        % number of chirps played per beat block
        numchirps4=length(beat4.chirptime_new);
        
        %         EOD=Ch1.values';
        glbstim=Ch3.values';
        
        zerocrossings=Ch5.times;
        zerocrossings_events=Ch5.values;
        ctimes=Ch4.times; % containes ALL triggers: the chirps but also the priming minute ones! so, we have to remove them!
        ctimes_events=Ch4.values;
        
        clear Ch1 Ch2 Ch3 Ch4 Ch5 Ch31 % not needed anymore
        
        prim_num=61;    % number of priming trigger
        numCT=101*ones(length(bfblocks),1); % total number of CTs per AM block
        
        % vector num_ct contains the number of chirp trigger per AM
        for I=1:length(bfblocks)
            if bfblocks(I)==4
                num_ct(I)=numchirps4;
                temp(I)=101;
            end
        end
        clear I
        for I=1:length(temp)
            if I==1
                prim_start(I)=1;
            else
                prim_start(I)=prim_start(I-1)+temp(I-1);
            end
        end
        prim_start(1)=1;
        prim_start(length(bfblocks)+1:end)=[];
        clear temp
        
        % now we build a vector containing num prime - num CT AM1 - num prime - num CT AM2 -...
        trigs=61*ones(length(num_ct)*2,1);
        for I=2:2:length(num_ct)*2
            trigs(I)=num_ct(I/2);
        end
        clear I
        %% get each chirp epoch, cut it accordingly and count responses
        
        % ahh, we have to account for that the last AM might not have all chirptrigger!!
        trig_num_tot=sum(ctimes_events(ctimes_events==1));  % calculates total number of trigger in recording!
        last_diff=sum(trigs)-trig_num_tot;  % calcuates the difference between the actual and the hypothetical chirp number for the last AM epoch
        trigs(end)=trigs(end)-last_diff;
        trig_num=sum(trigs)-(60*length(bfblocks));  % number of "epochs" excluding the priming minute!
        
        for I=1:length(trigs)
            if mod(I,2) == 0 % if even
                trigs2(I)=trigs(I);
            else % if odd
                trigs2(I)=trigs(I)-60;
            end
        end
        clear I
        
        for I=2:2:length(trigs2)
            trig_num2(I)=sum(trigs2(1:I));
        end
        clear I
        trig_num2(trig_num2==0)=[];
        trig_num2=trig_num2+1;
        trig_num2=[1 trig_num2];    % time stamps of the priming period
        
        ctimesind=find(ctimes_events==1);   % just the indices of the events
        zcind=find(zerocrossings_events==0);
        zerocrossings(zcind)=[];
        
        % now we have to delete the extra primer trigger...
        ind=zeros(length(bfblocks)-1,60);
        
        for I=1:length(prim_start)
            ind(I,:)=(prim_start(I)+1:1:(prim_start(I)+60));
        end
        ind=ind(:);
        ind=ind';
        
        ind=sort(ind);
        ind(ind>length(ctimesind))=[];
        ctimesind(ind)=[];
        ctimes_events_new=ctimes_events(ctimesind); % just the 'ones'
        ctimesnew=ctimes(ctimesind);    % just the time stamps of the events
        clear ind
        
        %%
        chirpwidth=zeros(500,trig_num);chirpwidth(find(chirpwidth==0))=NaN;
        chirpcount=zeros(1,trig_num);chirpcount(find(chirpcount==0))=NaN;chirplat=chirpcount;chirprate=chirpcount;
        chirpcountBL=zeros(1,trig_num);chirpcountBL(find(chirpcountBL==0))=NaN;chirprateBL=chirpcountBL;
        phase=zeros(500,trig_num);phase(find(phase ==0))=NaN;sctimes=phase;
        chirpFR=chirpwidth;
        phaseBL=zeros(500,trig_num);phaseBL(find(phaseBL ==0))=NaN;
        chirpwidthBL=zeros(500,trig_num);chirpwidthBL(find(chirpwidthBL==0))=NaN;chirpFRBL=chirpwidth;
        EODf=zeros(length(trig_num),1);EODf(find(EODf==0))=NaN;
        EODfbl=zeros(length(trig_num),1);EODfbl(find(EODfbl==0))=NaN;
        for I=1:trig_num
            BL=ismember(I,trig_num2);
            if BL==1     % baseline activity...
                epoch_start=ctimesnew(I);
                epoch_stop=epoch_start+60;
                zerocrossingstemp=zerocrossings(find(zerocrossings>epoch_start & zerocrossings<epoch_stop));  % takes 0Xings of EOD that are within the epoch
                ind=find(diff(zerocrossingstemp)<1/1500);   % removes artefacts (freqs > 1500Hz)
                zerocrossingstemp=zerocrossingstemp(setdiff(1:1:length(zerocrossingstemp),ind));
                feod=1./diff(zerocrossingstemp);    % converts into frequency
                oldaxis=zerocrossingstemp(1:end-1);
                timetemp=(epoch_start:1/10000:epoch_stop);
                timetemp=timetemp';
                newfeod=interp1(oldaxis,feod,timetemp,'linear');       % adaption to different sampling frequencies
                sinds=find(isnan(newfeod)==1);
                sinds1=find(isnan(newfeod)==0);
                newfeod(sinds)=mean(newfeod(sinds1));
                [B111,A111]=butter(2,0.01);     % filters feod
                newfeodfilt=(filtfilt(B111,A111,newfeod));
                if mean(newfeodfilt)>phEOD-10; % accounts for the EODf exceeding the phaselocking frequency
                    EODfbl(I)=-3;   % if so, write -3
                else
                    EODfbl(I)=0;
                end
                AM=glbstim(round((epoch_start)*10000:(epoch_stop)*10000));
                
                % now we have to identify the small chirps and the big chirps! -> very important!
                % threshold the chirps
                [p,s,mu] = polyfit((1:numel(newfeodfilt))',newfeodfilt,7);
                f_y = polyval(p,(1:numel(newfeodfilt))',[],mu);
                newfeodfilt_det = newfeodfilt - f_y;        % Detrend data
                timetempnew=(1/10000:1/10000:(length(AM)/10000));
                if length(newfeodfilt_det)<length(timetempnew)
                    timetempnew=timetempnew(1:length(newfeodfilt_det));
                elseif length(newfeodfilt_det)>length(timetempnew)
                    newfeodfilt_det=newfeodfilt_det(1:length(timetempnew));
                end
                if cca==1 || cca==3
                    threshold_chirp=ftresh2;
                else
                    threshold_chirp=ftresh;
                end
                [peaks,loc,wdt]=findpeaks(newfeodfilt_det,timetempnew,'Annotate','extents','WidthReference','halfheight','MinPeakHeight',threshold_chirp);
                %to delete miss-triggered chirps
                figure(002);hline=plot(timetempnew,newfeodfilt_det,'color',[0.5 0.5 0.5]); hold on;hline2=plot(loc,peaks,'ro');
                if cca==1
                    ylim([-5 100])
                else
                    ylim([-5 300])
                end
                leer=isempty(peaks);
                if leer==1
                else
                    qqe=input('delete something (YES=1; NO=)?: ');
                    close 002
                    if isempty(qqe)==1
                        qqe=0;
                    end
                    switch qqe
                        case 1
                            figure(003);hline=plot(timetempnew,newfeodfilt_det,'color',[0.5 0.5 0.5]); hold on;hline2=plot(loc,peaks,'ro');
                            title('brush peaks to be deleted and rigth click "remove"')
                            if cca==1
                                ylim([-5 100])
                            else
                                ylim([-5 300])
                            end
                            h = brush;
                            set(h,'Color',[.6 .2 .1],'Enable','on');
                            pause
                            xremaining=get(hline2,'XData');
                            yremeining=get(hline2,'YData');
                            removedIndex=~ismember(loc,xremaining);
                            ind=find(removedIndex==1);
                            ind2=0;
                            ind22=input('minus Hz: ');
                            if isempty(ind22)
                            else
                                ind2=ind22;
                            end
                            peaks(ind)=[];
                            peaks=peaks-ind2';
                            wdt(ind)=[];
                            loc(ind)=[];
                            close 003
                            figure(004);plot(timetempnew,newfeodfilt_det,'color',[0.5 0.5 0.5]); hold on;plot(loc,peaks,'ro')
                            if cca==1
                                ylim([-5 100])
                            else
                                ylim([-5 300])
                            end
                            pause(1)
                            close 004
                        case 2
                    end
                    clear qqe ind ind2
                end
                chirpft=peaks;   % in Hz
                chirpdurt=wdt;   % in sec
                loc=round(loc*10000);
                clear peaks wdt
                
                SC=find(chirpft<ftresh & chirpft>ftresh2);  % finds chirps with a lower freq excursion (SC);
                BC=find(chirpft>=ftresh); % finds chirps with a higher freq excursion (BC)
                AC=find(chirpft>ftresh2);
                
                if CA==1
                    indA=loc(SC);   % small chirps only
                    numb=SC;
                elseif CA==2
                    indA=loc(BC);   % big chirps only
                    numb=BC;
                elseif CA==3
                    indA=loc(AC);       % all chirps
                    numb=AC;
                end
                
                resp=isempty(indA);     % if the fish did not respons do nothing and set to NaN
                if resp==0
                    maso=atan2(imag(hilbert(AM)-mean(AM)),real(hilbert(AM))-mean(AM)); % this gets the phases of the AM!
                    phasesBL=maso(indA)*(360/pi); % gets the phase of the evoked chirp response in degrees
                    phasesBL=phasesBL(:);
                    phaseBL(1:length(phasesBL),I)=abs(phasesBL);
                    % number of responses; chirp duration, chirp frequency
                    chirpcountBL(:,I)=length(indA);   % counts the number of chirps
                    chirprateBL(:,I)=length(indA)/60;
                    chirpwidthBL(1:length(chirpdurt(numb)),I)=chirpdurt(numb);    % chirp duration
                    chirpFRBL(1:length(chirpft(numb)),I)=chirpft(numb);   % frequency excursion in Hz
                else
                    chirpcountBL(:,I)=0;
                    chirpratetBL(:,I)=0;
                end
                chirpwidth(:,I)=-1;
                chirpFR(:,I)=-1;
                chirplat(I)=-1;
                chirpcount(:,I)=-1;
                phase(:,I)=-1;
                chirprate(:,I)=-1;
                sctimes(:,I)=-1;
                EODf(:,I)=-1;
                clear newfeodfilt_det timetempnew f_y p s mu
                
            else
                epoch_start=ctimesnew(I)-0.1;
                epoch_stop=ctimesnew(I)+3.1;
                zerocrossingstemp=zerocrossings(find(zerocrossings>epoch_start & zerocrossings<epoch_stop));  % takes 0Xings of EOD that are within the epoch
                ind=find(diff(zerocrossingstemp)<1/1500);   % removes artefacts (freqs > 1500Hz)
                zerocrossingstemp=zerocrossingstemp(setdiff(1:1:length(zerocrossingstemp),ind));
                feod=1./diff(zerocrossingstemp);    % converts into frequency
                oldaxis=zerocrossingstemp(1:end-1);
                timetemp=(epoch_start:1/10000:epoch_stop);
                timetemp=timetemp';
                newfeod=interp1(oldaxis,feod,timetemp,'linear');       % adaption to different sampling frequencies
                sinds=find(isnan(newfeod)==1);
                sinds1=find(isnan(newfeod)==0);
                newfeod(sinds)=mean(newfeod(sinds1));
                [B111,A111]=butter(2,0.01);     % filters feod
                newfeodfilt=(filtfilt(B111,A111,newfeod));
                if mean(newfeodfilt)>phEOD-10; % accounts for the EODf exceeding the phaselocking frequency
                    EODf(I)=-3; % if so, write -3
                else
                    EODf(I)=0;
                end
                AM=glbstim(round((epoch_start)*10000:(epoch_stop)*10000));
                % now we have to identify the small chirps and the big chirps! -> very important!
                [p,s,mu] = polyfit((1:numel(newfeodfilt))',newfeodfilt,7);
                f_y = polyval(p,(1:numel(newfeodfilt))',[],mu);
                newfeodfilt_det = newfeodfilt - f_y;        % Detrend data
                newfeodfilt_det=newfeodfilt_det(1:end-1);
                timetempnew=(1/10000:1/10000:(length(AM)/10000));
                if length(newfeodfilt_det)<length(timetempnew)
                    timetempnew=timetempnew(1:length(newfeodfilt_det));
                elseif length(newfeodfilt_det)>length(timetempnew)
                    newfeodfilt_det=newfeodfilt_det(1:length(timetempnew));
                end
                if cca==1 || cca==3
                    threshold_chirp=ftresh2;
                else
                    threshold_chirp=ftresh;
                end
                [peaks,loc,wdt]=findpeaks(newfeodfilt_det,timetempnew,'Annotate','extents','WidthReference','halfheight','MinPeakHeight',threshold_chirp);
                wdt
                %to delete miss-triggered chirps
                figure(001);hline=plot(timetempnew,newfeodfilt_det,'color',[0.5 0.5 0.5]); hold on;hline2=plot(loc,peaks,'ro');
                if cca==1
                    ylim([-5 100])
                else
                    ylim([-5 300])
                end
                leer=isempty(peaks);
                if leer==1
                else
                    qqe=input('delete something (YES=1; NO= )?: ');
                    close 001
                    if isempty(qqe)==1
                        qqe=0;
                    end
                    switch qqe
                        case 1
                            figure(002);hline=plot(timetempnew,newfeodfilt_det,'color',[0.5 0.5 0.5]); hold on;hline2=plot(loc,peaks,'ro');
                            title('brush peaks to be deleted and rigth click "remove"')
                            if cca==1
                                ylim([-5 100])
                            else
                                ylim([-5 300])
                            end
                            h = brush;
                            set(h,'Color',[.6 .2 .1],'Enable','on');
                            pause
                            xremaining=get(hline2,'XData');
                            removedIndex=~ismember(loc,xremaining);
                            ind=find(removedIndex==1);
                            ind2=0;
                            ind22=input('minus Hz: ');
                            if isempty(ind22)
                            else
                                ind2=ind22;
                            end
                            peaks(ind)=[];
                            peaks=peaks-ind2';
                            wdt(ind)=[];
                            loc(ind)=[];
                            close 002
                            figure(003);plot(timetempnew,newfeodfilt_det,'color',[0.5 0.5 0.5]); hold on;plot(loc,peaks,'ro')
                            if cca==1
                                ylim([-5 100])
                            else
                                ylim([-5 300])
                            end
                            pause(1)
                            close 003
                        case 2
                    end
                    
                    clear qqe ind ind2
                end
                
                chirpft=peaks;   % in Hz
                chirpdurt=wdt;   % in sec
                loc=round(loc*10000);
                clear wdt peaks
                
                SC=find(chirpft<ftresh & chirpft>ftresh2);  % finds chirps with a lower freq excursion (SC);
                BC=find(chirpft>=ftresh); % finds chirps with a higher freq excursion (BC)
                AC=find(chirpft>ftresh2); % finds chirps with a higher freq excursion (all chirps)
                
                if CA==1
                    indA=loc(SC);   % small chirps only
                    numb=SC;
                elseif CA==2
                    indA=loc(BC);   % big chirps only
                    numb=BC;
                elseif CA==3
                    indA=loc(AC);       % all chirps
                    numb=AC;
                end
                
                resp=isempty(indA); % if the fish did not respond do nothing and set to NaN
                
                if resp==0
                    sctimes(1:length(indA),I)=timetempnew(indA)-0.1;   % for raster
                    latency=timetempnew(indA)-0.1;
                    latency(latency<0)=[];
                    latency(latency>=crit2)=[]; % deletes all chirps that occur outside the selected time-window
                    resp2=isempty(latency);
                    if resp2==1
                        chirpcount(:,I)=0;
                        chirprate(:,I)=0;
                    else
                        chirplat(:,I)=latency(1);   % latency of first echo in s
                        maso=atan2(imag(hilbert(AM)-mean(AM)),real(hilbert(AM))-mean(AM)); % this gets the phases of the AM!
                        phases=maso(indA)*(360/pi); % gets the phase of the evoked chirp response in degrees
                        phases=phases(:);
                        phase(1:length(phases),I)=abs(phases);
                        
                        % number of responses; chirp duration, chirp frequency
                        chirpcount(:,I)=length(indA);   % counts the number of chirps
                        chirprate(:,I)=length(indA)/crit2;
                        chirpwidth(1:length(chirpdurt(numb)),I)=chirpdurt(numb);    % chirp duration
                        chirpFR(1:length(chirpft(numb)),I)=chirpft(numb);   % frequency excursion in Hz
                    end
                else
                    chirpcount(:,I)=0;
                    chirprate(:,I)=0;
                end
                chirpcountBL(:,I)=-1;
                chirprateBL(:,I)=-1;
                chirpwidthBL(:,I)=-1;
                chirpFRBL(:,I)=-1;
                phaseBL(:,I)=-1;
                EODfbl(:,I)=-1;
                clear newfeodfilt_det timetempnew f_y p s mu
            end
            
            clear p s mu AM loc chirpdurt chirpft resp phasesBL latency indA timetemp timetempnew newfeodfilt newfeodfilt_det thresh meanfeod newfeod B111 A111 oldaxis feod zerocrossingstemp ind E_dur maso phases phasesBL epoch_start epoch_stop
            close all
        end
        %%
        sctimes(:,any(sctimes==-1))=[];
        chirpcountBL(chirpcountBL==-1)=[];
        chirprateBL(chirprateBL==-1)=[];
        chirplat(chirplat==-1)=[];
        chirpcount(chirpcount==-1)=[];
        chirprate(chirprate==-1)=[];
        EODfbl(EODfbl==-1)=[];
        EODf(EODf==-1)=[];
        phase(:,any(phase==-1))=[];  %columns
        chirpwidth(:,any(chirpwidth==-1))=[];  %columns
        chirpFR(:,any(chirpFR==-1))=[];  %columns
        chirpwidthBL(:,any(chirpwidthBL==-1))=[];  %columns
        chirpFRBL(:,any(chirpFRBL==-1))=[];  %columns
        phaseBL(:,any(phaseBL==-1))=[];  %columns
        
        chirplatT=chirplat;
        chirprateT=chirprate;
        chirpcountT=chirpcount;
        EODfT=EODf;
        clear chirplat chirprate chirpcount EODf
        %%
        % now we can calculate the responses to the beat and the phases
        % chirp number vector
        for I=1:length(bfblocks)
            beat=bfblocks(I);
            if beat==4
                if EODfbl(I)==-3
                    temp4BL(I)=NaN;
                    temp1BL(I)=NaN;temp2BL(I)=NaN;temp8BL(I)=NaN;temp16BL(I)=NaN;temp32BL(I)=NaN;temp64BL(I)=NaN;temp128BL(I)=NaN;
                else
                    temp4BL(I)=chirprateBL(I);
                    temp1BL(I)=NaN;temp2BL(I)=NaN;temp8BL(I)=NaN;temp16BL(I)=NaN;temp32BL(I)=NaN;temp64BL(I)=NaN;temp128BL(I)=NaN;
                end
                
            end
            clear beat
        end
        clear chirprateBL
        
        chirplat=zeros(1,40);chirplat(chirplat==0)=NaN;chirprate=chirplat;chirpcount=chirplat;EODf=chirplat;
        chirpnum=length(chirpcountT)-(40*(length(bfblocks)-1));
        for II=1:length(bfblocks)
            if bfblocks(II)==1
                if II==length(bfblocks)
                    temp=chirpnum;
                else
                    temp=numchirps1;
                end
                chirplat(1,1:temp)=chirplatT(1:temp);
                chirprate(1,1:temp)=chirprateT(1:temp);
                chirpcount(1,1:temp)=chirpcountT(1:temp);
                EODf(1,1:temp)=EODfT(1:temp);indweg=find(EODf(1,:)==-3);
                chirplat(1,indweg)=NaN;
                chirprate(1,indweg)=NaN;
                chirpcount(1,indweg)=NaN;
                clear indweg temp
            end
        end
        
        % echoresponse for beat
        temp4=zeros(1,40);
        temp4(temp4==0)=NaN;
        temp4l=temp4;temp4phase=temp4;
        temp4c=temp4;
        bf4temp=find(bfblocks==4);
        if length(bf4temp)==0
        else
            for III=1:length(bf4temp)
                temp4(III,1:length(chirprate(3,:)))=chirprate(3,:);
                temp4c(III,1:length(chirpcount(3,:)))=chirpcount(3,:);
                temp4l(III,1:length(chirplat(3,:)))=chirplat(3,:);
            end
        end
        
        clear chirprate chirpcount chirplat
        
        % echoresponse for different phases per beat
        chirpphases.b4p0=find(beat4.chirpphase==1);
        chirpphases.b4p12=find(beat4.chirpphase==0.125);
        chirpphases.b4p25=find(beat4.chirpphase==0.25);
        chirpphases.b4p37=find(beat4.chirpphase==0.375);
        chirpphases.b4p50=find(beat4.chirpphase==0.5);
        chirpphases.b4p62=find(beat4.chirpphase==0.625);
        chirpphases.b4p75=find(beat4.chirpphase==0.75);
        chirpphases.b4p87=find(beat4.chirpphase==0.875);
        
        % phases
        beat=[];
        for I=1:length(bfblocks)
            if bfblocks(I)==4
                temp=4*ones(1,num_ct(I));
                beat=[beat temp];
                clear temp
            end
            
        end
        
        phases4=zeros(500,(trig_num-length(bfblocks)));phases4(find(phases1==0))=NaN;dur4=phases4;freq4=phases4;sctimes4=phases4;
        clear I
        for I=1:trig_num-length(bfblocks)
            if beat(I)==4
                if EODfT(I)==-3
                else
                    phases4(1:length(phase(:,I)),I)=phase(:,I);
                    dur4(1:length(chirpwidth(:,I)),I)=chirpwidth(:,I);
                    freq4(1:length(chirpFR(:,I)),I)=chirpFR(:,I);
                    sctimes4(1:length(sctimes(:,I)),I)=sctimes(:,I);
                end
            end
        end
        clear phase chirpwidth chirpFR
        
        % baseline activity
        phasesBL4=zeros(500,(length(bfblocks)));phasesBL4(find(phasesBL4==0))=NaN;durBL4=phasesBL4;freqBL4=phasesBL4;
        for I=1:length(bfblocks)
            if bfblocks(I)==4
                phasesBL4(1:length(phaseBL(:,I)),I)=phaseBL(:,I);
                durBL4(1:length(chirpwidthBL(:,I)),I)=chirpwidthBL(:,I);
                freqBL4(1:length(chirpFRBL(:,I)),I)=chirpFRBL(:,I);
            end
        end
        clear phaseBL chirpwidthBL chirpFRBL
        
        phases4=phases4(:);
        phases4(isnan(phases4))=[];
        
        phasesBL4=phasesBL4(:);
        phasesBL4(isnan(phasesBL4))=[];
        
        [savename2 exten];
        %%
        % save data for later analysis
        % Baseline
        phaseBL.tphasesBL4=phasesBL4;chirprateBL.temp4BLs=temp4BL;chirpdurBL.tempd4BLs=durBL4;chirpFRBL.tempf4BLs=freqBL4;
        
        % Driven
        chirprate.temp4s=temp4;chirplatency.temp4ls=temp4l;phase.tphases4=phases4;chirpdur.tempd4s=dur4;chirpFR.tempf4s=freq4;sctime.temp4sc=sctimes4;
        
        cd([locationS])
        % this data can be found in the folder 'extracted_data'
        save([savename1 savename2 exten],'crit2','sctime','chirprateBL','phaseBL','chirpdurBL','chirpFRBL','chirprate','chirplatency','phase','chirpdur','chirpFR','chirpphases')
        
        keep FileList n FL cca location locationS phEODvect
    end
end
close all
